@@ -5,7 +5,7 @@ from typing import AsyncContextManager
 from async_timeout import asyncio
 from diskcache import Cache
 from threading import Lock
-
+from hamunafs.utils.singleton_wrapper import Singleton
 from hamunafs.utils.redisutil import XRedis
 from hamunafs.utils.nsqmanager import MQManager
 from hamunafs.backends import BackendBase, backend_factory
@@ -25,7 +25,7 @@ try:
 except:
     pass
 
-class Client:
+class Client(Singleton):
     @staticmethod
     def get_client(host, redis_client: XRedis, mq_manager: MQManager, async_mq_mode=True, cache_path='../cache', custom_async_loop=None):
         client = Client(host, redis_client, mq_manager, async_mq_mode)
